@@ -16,6 +16,7 @@
 #
 
 from py4j.java_gateway import JavaObject
+from py4j.java_collections import JavaArray
 from pyspark.ml.linalg import DenseVector, DenseMatrix
 from pyspark.ml.param import TypeConverters
 from pyspark.ml.util import _jvm
@@ -195,6 +196,34 @@ class H2OTypeConverters(object):
 
         return convert
 
+    @staticmethod
+    def toNullableListBoolean():
+        def convert(value):
+            if value is None:
+                return None
+            else:
+                return H2OTypeConverters.toListBoolean()(value)
+
+        return convert
+
+    @staticmethod
+    def toListBoolean():
+        def convert(value):
+            if value is None:
+                raise TypeError("None is not allowed.")
+            else:
+                valueForConversion = value
+                if isinstance(value, JavaObject):
+                    valueForConversion = list(value)
+
+                if TypeConverters._can_convert_to_list(valueForConversion):
+                    valueForConversion = TypeConverters.toList(valueForConversion)
+                    if all(map(lambda v: type(v) == bool, valueForConversion)):
+                        return [bool(v) for v in valueForConversion]
+                raise TypeError("Could not convert %s to list of booleans" % valueForConversion)
+
+        return convert
+
     @staticmethod
     def toNullableListInt():
         def convert(value):
@@ -401,6 +430,18 @@ class H2OTypeConverters(object):
 
         return convert
 
+    @staticmethod
+    def toNullableListJavaObject():
+        def convert(value):
+            if value is None:
+                return None
+            elif isinstance(value, list) or isinstance(value, JavaArray):
+                return [H2OTypeConverters.toJavaObj()(obj) for obj in value]
+            else:
+                raise TypeError("Invalid type: " + str(type(value)))
+
+        return convert
+
     @staticmethod
     def toDictionaryWithAnyElements():
         def convert(value):
@@ -515,7 +556,11 @@ class H2OTypeConverters(object):
         if jdf is None:
             return None
         elif isinstance(jdf, JavaObject):
-            sqlContext = SparkSession.builder.getOrCreate()._wrapped
+            session = SparkSession.builder.getOrCreate()
+            if hasattr(session, '_wrapped'):
+                sqlContext = session._wrapped
+            else:
+                sqlContext = session  # Spark 3.3+ utilizes SparkSession instead of SQLContext
             return DataFrame(jdf, sqlContext)
         else:
             raise TypeError("Invalid type.")
